# This is my first python package to learn how to make a python package

- this uses pypi to deploy a pip install
- it uses branches on git to controll software
- it uses git hub actions to upload to pypi

To install:

```bash
pip install example_python_package_Blitan
```